Index: chrome/browser/ui/webui/ntp/app_launcher_handler.cc |
diff --git a/chrome/browser/ui/webui/ntp/app_launcher_handler.cc b/chrome/browser/ui/webui/ntp/app_launcher_handler.cc |
index 5ca61e37459c936c1ca81edb469c2ad7397015f4..abf809463a08ba323fed2e872d3769ed7f4615f7 100644 |
--- a/chrome/browser/ui/webui/ntp/app_launcher_handler.cc |
+++ b/chrome/browser/ui/webui/ntp/app_launcher_handler.cc |
@@ -226,10 +226,12 @@ void AppLauncherHandler::FillAppDictionary(DictionaryValue* dictionary) { |
const ExtensionList* extensions = extensions_service_->extensions(); |
ExtensionList::const_iterator it; |
for (it = extensions->begin(); it != extensions->end(); ++it) { |
// Don't include the WebStore. |
// The WebStore launcher gets special treatment in ntp/apps.js. |
+ // The Cloud Print app should not be displayed in the NTP. |
if ((*it)->is_app() && |
- (*it)->id() != extension_misc::kWebStoreAppId) { |
+ (*it)->id() != extension_misc::kWebStoreAppId && |
+ (*it)->id() != extension_misc::kCloudPrintAppId) { |
DictionaryValue* app_info = new DictionaryValue(); |
CreateAppInfo(*it, extensions_service_->extension_prefs(), app_info); |
list->Append(app_info); |
@@ -239,7 +241,8 @@ void AppLauncherHandler::FillAppDictionary(DictionaryValue* dictionary) { |
extensions = extensions_service_->disabled_extensions(); |
for (it = extensions->begin(); it != extensions->end(); ++it) { |
if ((*it)->is_app() && |
- (*it)->id() != extension_misc::kWebStoreAppId) { |
+ (*it)->id() != extension_misc::kWebStoreAppId && |
+ (*it)->id() != extension_misc::kCloudPrintAppId) { |
DictionaryValue* app_info = new DictionaryValue(); |
CreateAppInfo(*it, extensions_service_->extension_prefs(), app_info); |
list->Append(app_info); |
@@ -226,10 +226,12 @@ void AppLauncherHandler::FillAppDictionary(DictionaryValue* dictionary) { |
ExtensionList::const_iterator it; |
for (it = extensions->begin(); it != extensions->end(); ++it) { |
- // Don't include the WebStore. |
+ // Don't include the WebStore and the Cloud Print app. |
// The WebStore launcher gets special treatment in ntp/apps.js. |